BACKUP_PATH = "/home/backups/"
MYSQL_BACKUP = True

CONF_FILE = "/etc/dropbox_backup.conf"

CHUNK_SIZE = 1024 * 10000
DROPBOX_BASE_URL = "https://api.dropbox.com/1"
DROPBOX_CONTENT_URL = "https://api-content.dropbox.com/1"